/*
 * Copyright 2012-2013 Canoo Engineering AG.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opendolphin.core.server.action

import org.opendolphin.core.comm.EmptyNotification
import org.opendolphin.core.server.comm.ActionRegistry
import groovy.transform.CompileStatic
import groovy.util.logging.Log

/**
 * An action that does nothing on the server.
 * It is only used to hook into the communication at a known point
 * such that the onFinished handler for the command is executed
 * in the expected sequence.
 */

@CompileStatic
@Log
class EmptyAction implements ServerAction {

    void registerIn(ActionRegistry registry) {
        registry.register(EmptyNotification) { EmptyNotification command, response ->
            log.finest "empty action reached - doing nothing on the server"
        }
    }
}
